@@ -2,18 +2,18 @@
 """
 This file is part of gfs_sampler.
 
-GFS is free software: you can redistribute it and/or modify
+gfs_sampler is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.
 
-GFS is distributed in the hope that it will be useful,
+gfs_sampler is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with GFS. If not, see <https://www.gnu.org/licenses/>.
+along with gfs_sampler. If not, see <https://www.gnu.org/licenses/>.
 
 Created on Sat Feb  3 18:56:04 2018
 """
@@ -550,4 +550,4 @@ def sample(df1, df2, formula_array, family_array, N, I, T, burnin, interval):
     P_df = pd.DataFrame(full_P.transpose())
     return(P_df.replace(-1, np.nan))
 
-from GFS.distributions import *
+from gfs_sampler.distributions import *
